@@ -3,6 +3,7 @@
 #include <sys/time.h>
 #include <string.h>
 #include <math.h>
+#include <R.h>
 #define CROSS_SINE(v0, v1) ((v0).x * (v1).y - (v1).x * (v0).y)
 #define LENGTH(v0) (sqrt((v0).x * (v0).x + (v0).y * (v0).y))
 #ifdef __STDC__
@@ -306,6 +307,8 @@ static int traverse_polygon(mcur, trnum, from, dir)
   int retval=0;
   int do_switch = FALSE;
 
+  //if ((trnum <= 0) || visited[trnum]) return 0;
+
   visited[trnum] = TRUE;
 
   /* We have much more information available here. */
@@ -793,7 +796,7 @@ int testclock(double *x,double *y,int last) {
 
 
 /* Generate a random permutation of the segments 1..n */
-int generate_random_ordering(int n) {	
+/*int generate_random_ordering(int n) {	
 	int lig, i,j, k;
 	double z;
 	choose_idx = 1;
@@ -809,6 +812,25 @@ int generate_random_ordering(int n) {
 		permute[k] = z;
 	}
 	return 0;
+}*/
+int generate_random_ordering(int n) {	
+	int lig, i,j, k;
+	double z;
+	GetRNGstate();
+	choose_idx = 1;
+	for (i = 1; i <= n; i++)
+		permute[i]=i;
+	lig = permute[0];
+	for (i=1; i<=lig-1; i++)
+	{	j=lig-i+1;
+		k = (int) (j*unif_rand()+1);
+		if (k>j) k=j;
+		z = permute[j];
+		permute[j]=permute[k];
+		permute[k] = z;
+	}
+	PutRNGstate();
+	return 0;
 }
 
 /* Return the next segment in the generated random ordering of all the */
@@ -2104,3 +2126,81 @@ int is_point_inside_polygon(vertex)
   return _greater_than_equal_to(&seg[rseg].v1, &seg[rseg].v0);
 }
 
+int c_triangulate(int *npoly, int *tabpt, int *nptTot,double *vertX, double *vertY, int *ntri, double *X1, double *Y1,double *X2, double *Y2,double *X3, double *Y3) {
+  int i,j,k,l;
+  int **triangles;
+  double **vertices;
+  double *x,*y;
+  tabintalloc(&triangles,*ntri,3);
+  taballoc(&vertices,*nptTot+1,2);
+  l=0;
+  for(i=0;i<*npoly;i++) {
+    int npt=tabpt[i];
+    vecalloc(&x,npt+1);
+    vecalloc(&y,npt+1);
+    for(j=1;j<=npt;j++) {
+      k=j+l-1;
+      x[j]=vertX[k];
+      y[j]=vertY[k];
+    }
+    if(i==0) {
+      if(testclock(x,y,npt)) { /*clockwise order*/
+k=npt;
+        for(j=1;j<=npt;j++) {
+          vertices[j+l][0]=x[k];
+          vertices[j+l][1]=y[k];
+          k--;
+        }
+      }
+      else { /*anti-clockwise order*/
+for(j=1;j<=npt;j++) {
+  vertices[j+l][0]=x[j];
+  vertices[j+l][1]=y[j];
+}
+      }
+    }
+    else {
+      if(!testclock(x,y,npt)) { /*anti-clockwise order*/
+k=npt;
+        for(j=1;j<=npt;j++) {
+          vertices[j+l][0]=x[k];
+          vertices[j+l][1]=y[k];
+          k--;
+        }
+      }
+      else { /*clockwise order*/
+for(j=1;j<=npt;j++) {
+  vertices[j+l][0]=x[j];
+  vertices[j+l][1]=y[j];
+}
+      }
+    }
+    l+=npt;
+    freevec(x);
+    freevec(y);
+  }
+  
+  /*Test de l'unicite des points*/
+  for(i=2;i<=*nptTot;i++) {
+    for(j=1;j<i;j++) {
+      if((vertices[i][0]==vertices[j][0])&&(vertices[i][1]==vertices[j][1])) {
+        Rprintf("Error : Duplicate input vertices\n");
+        return -1;
+      }
+    }
+  }
+  triangulate_polygon(*npoly,tabpt,vertices,triangles);
+  for(i=0;i<*ntri;i++) {
+    X1[i]=vertices[triangles[i][2]][0];
+    Y1[i]=vertices[triangles[i][2]][1];
+    X2[i]=vertices[triangles[i][1]][0];
+    Y2[i]=vertices[triangles[i][1]][1];
+    X3[i]=vertices[triangles[i][0]][0];
+    Y3[i]=vertices[triangles[i][0]][1];
+  }
+  freeinttab(triangles);
+  freetab(vertices);
+  return 0;
+}
+
+
